/*******************************************************************************
*		Instrument Validation
*******************************************************************************/

********************************************************************************
***** Clinician FE first stage *****
********************************************************************************

frame change default
use  "$data/${filelab}_final.dta", clear

ivreghdfe recid ($fs_out = z_$fs_out ) if age < 26, a($time_fe ) clust( $clust ) first
		local f_kp1 : di %9.0fc e(widstat)
		local f_kp1 = strltrim("`f_kp1'")
ivreghdfe recid ($fs_out = z_$fs_out ) $demogs if age < 26, a($time_fe ) clust( $clust ) first
		local f_kp2 : di %9.0fc e(widstat)
		local f_kp2 = strltrim("`f_kp2'")
ivreghdfe recid ($fs_out = z_$fs_out ) if age >= 26, a($time_fe ) clust( $clust ) first
		local f_kp3 : di %9.0fc e(widstat)
		local f_kp3 = strltrim("`f_kp3'")
ivreghdfe recid ($fs_out = z_$fs_out ) $demogs if age >= 26, a($time_fe ) clust( $clust ) first
		local f_kp4 : di %9.0fc e(widstat)
		local f_kp4 = strltrim("`f_kp4'")

eststo clear
eststo:  reghdfe $fs_out  z_$fs_out  if age < 26, a($time_fe ) clust( $clust )
		estadd local t_fe "Yes"
		estadd local f_kp "`f_kp1'"
		estadd local demogs "No"
		gen tay_sample = e(sample)
eststo:  reghdfe $fs_out z_$fs_out $demogs  if age < 26, a($time_fe ) clust( $clust )
		estadd local t_fe "Yes"
		estadd local f_kp "`f_kp2'"
		estadd local demogs "Yes"
		
eststo:  reghdfe $fs_out  z_$fs_out  if age >= 26, a($time_fe ) clust( $clust )
		estadd local t_fe "Yes"
		estadd local f_kp "`f_kp3'"
		estadd local demogs "No"
		gen adult_sample = e(sample)
		
eststo:  reghdfe $fs_out z_$fs_out $demogs  if age >= 26, a($time_fe ) clust( $clust )
		estadd local t_fe "Yes"
		estadd local f_kp "`f_kp4'"
		estadd local demogs "Yes"

#delimit ;
	esttab using "${tables}/${filelab}_fs_regs.tex",
		booktabs
		style(tex) label notype
		keep(z_$fs_out)
		cells((b(star fmt(%9.3f))) (se(fmt(%9.3f)par)))
		starlevels(* 0.10 ** 0.05 *** 0.01)
		substitute("\_" "_")
		stats( f_kp t_fe demogs N,
			labels( "Kleibergen-Paap F"
					"Time Fixed Effects" "Baseline Controls" "Observations")
			fmt(0 0 0 0))
		replace noabbrev
		numbers collabels(none) eqlabels(none) mlabels(none)
		title("First Stage Regressions for Initial Assessment of ${fs_lab}")
		mgroups("Transition Age" "Adults", pattern(1 0 1 0)
				prefix(\multicolumn{@span}{c}{)
				suffix(}) span erepeat(\cmidrule(lr){@span}))
		prehead("\begin{table}[htbp]"
				"\centering"
				"\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}"
				"\caption{@title}\label{tab:${filelab}_first_stage}"
				"\begin{tabular}{p{.35\linewidth}*{@E}{c}}"
				"\toprule"
				)
		postfoot("\bottomrule"
				 "\multicolumn{@span}{p{\textwidth}}{\footnotesize Notes: We report the first stage results of a linear probability model stratified by age group. The binary outcome of interest is the initial assessment of an inmate's mental health needs being either none/low or moderate/severe. The propensity to assign the most severe score is estimated using data from other cases assigned to the clinician following the procedure described in the text. Columns (1) and (2) limit the sample to TAY whereas columns (3) and (4) limit the sample to adults. Columns (1) and (3) show the results by controlling only for ${time_lab} fixed effects, whereas Columns (2) and (4) also include the inmate baseline controls as shown in Table 1. Each column gives the corresponding clinician and inmate robust two-way clustered standard errors in parentheses. Robust (Kleibergen-Paap) first stage F is reported. Note, this is equivalent to the effective F-statistic of Montiel Olea and Pflueger (2013) in this case of a single instrument. * p$<$0.10, ** p$<$0.05, *** p$<$0.01}"
				"\end{tabular}"
				"\end{table}"
				)
		;
#delimit cr
	
* Output table to word format
if "${filelab}" == "mis" {
	#delimit ;
		esttab using "$tables/first_stage_tables", replace label
			rtf onecell
			keep(z_$fs_out)
		cells((b(star fmt(%9.3f))) (se(fmt(%9.3f)par)))
		starlevels(* 0.10 ** 0.05 *** 0.01)
		stats( f_kp t_fe demogs N,
			labels( "Kleibergen-Paap F"
					"Time Fixed Effects" "Baseline Controls" "Observations")
			fmt(%9.0fc 0 0 %9.0fc)
			)
		noabbrev numbers collabels(none) eqlabels(none) mlabels(none)
		title("First Stage Regressions for Initial Assessment of ${fs_lab}")
		mgroups("Transition Age" "Adults", pattern(1 0 1 0))
		addnotes("Notes: We report the first stage results of a linear probability model stratified by age group. The binary outcome of interest is the initial assessment of an inmate's mental health needs being either none/low or moderate/severe. The propensity to assign the most severe score is estimated using data from other cases assigned to the clinician following the procedure described in the text. Columns (1) and (2) limit the sample to TAY whereas columns (3) and (4) limit the sample to adults. Columns (1) and (3) show the results by controlling only for ${time_lab} fixed effects, whereas Columns (2) and (4) also include the inmate baseline controls as shown in Table 1. Each column gives the corresponding clinician and inmate robust two-way clustered standard errors in parentheses. Robust (Kleibergen-Paap) first stage F is reported. Note, this is equivalent to the effective F-statistic of Montiel Olea and Pflueger (2013) in this case of a single instrument. * p$<$0.10, ** p$<$0.05, *** p$<$0.01"
				)
			;
		#delimit cr
}
else {
	di "Label: $filelab" 
	#delimit ;
		esttab using "$tables/first_stage_tables", append label
			rtf onecell
			keep(z_$fs_out)
		cells((b(star fmt(%9.3f))) (se(fmt(%9.3f)par)))
		starlevels(* 0.10 ** 0.05 *** 0.01)
		stats( f_kp t_fe demogs N,
			labels( "Kleibergen-Paap F"
					"Time Fixed Effects" "Baseline Controls" "Observations")
			fmt(%9.0fc 0 0 %9.0fc)
			)
		noabbrev numbers collabels(none) eqlabels(none) mlabels(none)
		title("First Stage Regressions for Initial Assessment of ${fs_lab}")
		mgroups("Transition Age" "Adults", pattern(1 0 1 0))
		addnotes("Notes: We report the first stage results of a linear probability model stratified by age group. The binary outcome of interest is the initial assessment of an inmate's mental health needs being either none/low or moderate/severe. The propensity to assign the most severe score is estimated using data from other cases assigned to the clinician following the procedure described in the text. Columns (1) and (2) limit the sample to TAY whereas columns (3) and (4) limit the sample to adults. Columns (1) and (3) show the results by controlling only for ${time_lab} fixed effects, whereas Columns (2) and (4) also include the inmate baseline controls as shown in Table 1. Each column gives the corresponding clinician and inmate robust two-way clustered standard errors in parentheses. Robust (Kleibergen-Paap) first stage F is reported. Note, this is equivalent to the effective F-statistic of Montiel Olea and Pflueger (2013) in this case of a single instrument. * p$<$0.10, ** p$<$0.05, *** p$<$0.01"
				)
			;
		#delimit cr	
}

	
tempfile sampfile
save `sampfile'
eststo clear


*** Histogram of IV ***
foreach subsamp in "tay" "adult" {
	frame copy default temp_df, replace
	frame change temp_df
	if "`subsamp'" == "tay" {
		keep if age < 26
	    local varlab "Transition Age"
	}
	else {
	    keep if age >= 26
		local varlab "Adult"
	}
	
	* get FE residuals
	qui reghdfe $fs_out z_$fs_out, a($time_fe ) residuals(resid_$fs_out )
	
	gen resid = resid_$fs_out + _b[z_$fs_out]*z_$fs_out + _b[_cons]

	* run lpoly regression on residuals
	cap drop fs_x fs_y
	cap drop se
	/* This is a local linear regression with Gaussian kernel weighting.*/
	lpoly resid z_$fs_out, ///
			 kern(gaussian) degree(1) bw(.35) n(100) gen(fs_x fs_y) se(se) nograph

	* store data
	preserve
	tempfile fs_xy
		keep fs_x fs_y se
		drop if fs_x==.
		sort fs_x
	save `fs_xy'
	restore

	* create first stage and distribution of instrument figure
	preserve
	keep z_$fs_out

	append using `fs_xy'

	gen upper = fs_y + 1.96*se
	gen lower = fs_y - 1.96*se

	local range_val 0.6		// sets graph x-axis range
	#delimit ;
	twoway hist z_$fs_out if abs(z_$fs_out)<= `range_val', frac width(0.025) color(gs8%40)
		|| line fs_y fs_x if abs(fs_x)<=`range_val', lc(black) lw(.5) lp(solid) yaxis(2)
		|| line upper fs_x if abs(fs_x)<=`range_val', lc(gs8) lw(.3) yaxis(2) lp(dash)
		|| line lower fs_x if abs(fs_x)<=`range_val', lc(gs8) lw(.3) yaxis(2) lp(dash)
		graphregion(color(white))
		title("Distribution and First Stage of" "${fs_lab} for `varlab'")
		xtitle("Distribution of Initial Assessment of" "${fs_lab} Propensity")
		xlabel(-`range_val'(0.1)`range_val', format(%9.2fc))
		ylabel(, format(%9.2fc))
		ylabel(, format(%9.2fc) axis(2))
		ytitle("Fraction of Sample", axis(1))
		ytitle("Residualized Propensity for Initial Assessment of" "${fs_lab}" "for `varlab'", axis(2))
		legend(off);
	#delimit cr
	restore

	graph export "${figures}/${filelab}_FirstStage_`subsamp'.pdf", replace
	
	frame change default
	frame drop temp_df
}

********************************************************************************
*** Balance Table ***
********************************************************************************
// adds padding
foreach var of varlist $demogs {
		local varlab : variable label `var'
		label variable `var' "\hspace{1em}`varlab'"
	}

* tercile means
cap xtile tercile=z_$fs_out, n(3)

* save state
tempfile balance
save `balance'

forval i = 0/1 {

	use `balance', clear
	if `i' == 0 {
		keep if age < 26
		local age_samp "Transition Age Youth"
		local file_label "tay"
		local pfoot "\midrule"
		local phead "\caption{@title}\label{tab:balance_${filelab}} \begin{tabular}{p{.4\linewidth}*{5}{>{\centering\arraybackslash}p{.09\textwidth}}} \toprule \\"
	}
	else {
		keep if age >= 26
		local age_samp "Adults"
		local file_label "adults"
		local phead " \\ "
		#delimit ;
		local pfoot "\bottomrule
					\multicolumn{6}{p{\linewidth}}{\footnotesize Notes: Data is from a large county correctional complex. Time fixed effects include ${time_lab} fixed effects. Clinician and inmate two-way clustered standard errors shown in parentheses. \newline * p$<$0.10, ** p$<$0.05, *** p$<$0.01}\\
					\end{tabular}"
					;
		#delimit cr
	}

	* gets the means
	preserve
		collapse z_$fs_out $demogs, by(tercile)
		drop if tercile == .
		drop tercile
		xpose, clear varname
		forval i = 1/3 {
			rename v`i' tercile`i'
		}
		mkmat tercile1, mat(tm1) rownames(_varname)
		mkmat tercile2, mat(tm2) rownames(_varname)
		mkmat tercile3, mat(tm3) rownames(_varname)
	restore

* Gets the p-values for balance table
	cap mat drop p_t2 p_t3
	forval i = 2/3 {
		local j = 0 // matrix initialization counter
		foreach var of varlist z_$fs_out $demogs {
		// omit tercile 2 then 3
		qui reghdfe `var' tercile if tercile != `i', a($time_fe) vce(cluster $clust)
			local t = _b[tercile]/_se[tercile]
			local p = 2*ttail(e(df_r),abs(`t'))
			if `j' == 0 {
				matrix p_t`i' = `p'
				di "if"
			}
			else {
				di "else"
				matrix p_t`i' = p_t`i' \ `p'
			}
			local j = `j' + 1
		}
		mat rownames p_t`i' = z_$fs_out $demogs
	}


	eststo clear
	ereturn clear
	// tercile means
	estadd matrix bal1 = tm1'
	estadd matrix bal2 = tm2'
	estadd matrix bal3 = tm3'
	// p-values
	// matrix p_t2 is omitting tercile 2; matrix p_t3 is omitting tercile 3
	estadd matrix bal4 = p_t3'
	estadd matrix bal5 = p_t2'

	#delimit ;
	esttab using "${tables}/${filelab}_balance_`file_label'.tex",
		cells("bal1(fmt(3)) bal2(fmt(3)) bal3(fmt(3)) bal4(fmt(3) par) bal5(fmt(3) par)")
		substitute("\_" "_")
		replace label nostar booktabs nonumbers
		unstack noobs nonote nomtitle wrap varwidth(25)
		title("Balance of Instrument and Inmate Characteristics for ${fs_lab}")
		collabels("Bottom Tercile" "Middle Tercile" "Top Tercile" "Middle v. Bottom P-Value" "Top v. Bottom P-Value")
		refcat(asian `"\rule{0pt}{4ex}Inmate Characteristics"', nolabel)
		prehead(`phead'
				"\multicolumn{6}{l}{\textbf{`age_samp'}}\\"
				"\midrule")
		posthead("\midrule")
		postfoot(`pfoot')
	;
	#delimit cr
}




use  "$data/${filelab}_final.dta", clear
********************************************************************************
*** Randomization Test ***
********************************************************************************
// removes padding
use `sampfile', clear
foreach var of varlist $demogs {
		local label : variable label `var'
		local label : subinstr local label "\hspace{1em}" "", all
		label variable `var' "`label'"
	}


eststo clear
eststo: reghdfe $fs_out $demogs if age < 26 & tay_sample==1, a($time_fe ) vce(cluster $clust)
qui testparm*
estadd scalar F_p = r(p)
estadd local t_fe "Yes"

eststo: reghdfe z_$fs_out $demogs if age < 26 & tay_sample==1, a($time_fe ) vce(cluster $clust)
qui testparm*
estadd scalar F_p = r(p)
estadd local t_fe "Yes"

eststo: reghdfe $fs_out $demogs if age >= 26 & adult_sample==1, a($time_fe ) vce(cluster $clust)
qui testparm*
estadd scalar F_p = r(p)
estadd local t_fe "Yes"

eststo: reghdfe z_$fs_out $demogs if age >= 26 & adult_sample==1, a($time_fe ) vce(cluster $clust)
qui testparm*
estadd scalar F_p = r(p)
estadd local t_fe "Yes"

#delimit ;
	esttab using "${tables}/${filelab}_randomization.tex",
		booktabs
		style(tex) label notype
		cells((b(star fmt(%9.3f))) (se(fmt(%9.3f)par)))
		starlevels(* 0.10 ** 0.05 *** 0.01)
		stats(t_fe F N,
			labels("Time fixed effects" "F-test" "Observations")
			fmt(%9.0fc %9.0fc  %9.0fc ))
			drop(_cons)
			substitute("\_" "_")
			replace noabbrev
			title("Test of Randomization for ${fs_lab}")
			collabels(none) eqlabels(none) mlabels("${fs_lab}" "Z: ${fs_lab}" "${fs_lab}" "Z: ${fs_lab}") 
			mgroups("Transition Age" "Adults", pattern(1 0 1 0)
				prefix(\multicolumn{@span}{c}{)
				suffix(}) span erepeat(\cmidrule(lr){@span}))
			prehead("\begin{table}[htbp]"
				"\centering"
				"\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}"
				"\caption{@title}\label{tab:${filelab}_randomization}"
				"\begin{tabular}{p{.32\linewidth}*{@E}{>{\centering\arraybackslash}p{.14\textwidth}}}"
				"\toprule")
		postfoot("\bottomrule"
				"\multicolumn{@span}{p{\textwidth}}{\footnotesize Notes: These linear probability models control for the baseline characteristics used in the instrumental variables analyses. The binary dependent variable in columns (1) and (3) is being assigned a moderate-to-severe mental illness score at initial assessment. The dependent variable in columns (2) and (4) is the propensity to assign a high or low score to inmates. Time fixed effects include ${time_lab} fixed effects. Clinician and inmate two-way clustered standard errors shown in parentheses. * p$<$0.10, ** p$<$0.05, *** p$<$0.01}"
				"\end{tabular}"
				"\end{table}")
		;
#delimit cr





// to save time, skip for supplemental analyses !inlist("${filelab}", "mis_hisp", "mis_complier", "mis_trunc", "mis_yr_18_19", "mis_over500cases", "fel_complier", "fel_trunc", "fel_yr_18_19", "fel_over500cases")
if (inlist("${filelab}","mis","fel")) {
    
	********************************************************************************
	**** Monotonicity
	********************************************************************************
	*test Monotonicity
	cap file close mono_table
	macro drop mono_table
	file open mono_table using "$tables/${filelab}_mono_table.tex", write text replace
	#delimit ;
		file write mono_table "\begin{table}[htbp]" _n
			"\centering" _n
			"\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" _n
			"\caption{Frandsen, Lefgren, Leslie (2020) Test of Joint Null of Exclusion and Monotonicity}\label{tab:mono}" _n
			"\begin{tabular}{p{.5\linewidth}*{1}{c}}" _n
			"\toprule" _n
		  "Outcome & FLL P-Value\\ " _n
			"\midrule" _n
		;
	#delimit cr
	//file close mono_table
	foreach y of varlist $outcomes {
		local ylabel : variable label `y'
		testjfe `y' $fs_out clinician_dd*, numknots(5) covariates($time_fe $demogs ) fitweight(.5)
		file write mono_table "`ylabel'   &  " %7.3f (r(pval)) " \\" _n
	}
	#delimit ;
		file write mono_table "\bottomrule"_n
			"\multicolumn{2}{p{.7\linewidth}}{\footnotesize Notes: This table presents results from the test proposed in Frandsen, Lefgren, and Leslie (2020) for the joint null hypothesis that the monotonicity and exclusion restrictions hold. Rejecting the null (a significant p-value) suggests that the monotonicity and the exclusion restrictions do not jointly hold. This test was implemented in Stata via the package testjfe (Frandsen, 2020).}\\"_n
			"\end{tabular}"_n "\end{table}"
		;
	#delimit cr
	file close mono_table


	* average monotonicity
	foreach subsamp in "tay" "adult" {
		frame copy default temp_df, replace
		frame change temp_df
		if "`subsamp'" == "tay" {
			keep if age < 26
			local varlab "Transition Age"
		}
		else {
			keep if age >= 26
			local varlab "Adult"
		}
		
	eststo clear
	foreach samp in "male == 1" "male == 0" "black == 1" "white == 1" "hispanic == 1" {
		cap eststo: reghdfe $fs_out z_$fs_out $demogs if `samp' , a($time_fe) clust($clust)
		estadd local t_fe "Yes"
		estadd local controls "Yes"
	}

	esttab , se nostar keep(z_$fs_out ) label
	matrix C = r(coefs)
	matrix S = r(stats)

	local rnames `samp'
	local models : coleq C
	local models : list uniq models
	local i 0
	foreach name of local rnames {
		local ++i
		local j 0
		capture matrix drop b
		capture matrix drop se

		foreach model of local models {
			local ++j
			matrix tmp = C[`i', 2*`j'-1]
			if tmp[1,1]<. {
				matrix colnames tmp = `model'
				matrix b = nullmat(b), tmp
				matrix tmp[1,1] = C[`i', 2*`j']
				matrix se = nullmat(se), tmp
			}
		}
		ereturn post b
		qui estadd matrix se
		eststo `name'
	}

	if "`subsamp'" == "tay" {
	    local footnote 
	}
	else {
	    local footnote "\multicolumn{6}{p{\linewidth}}{\footnotesize Notes: This table presents a test for statisfying average monotonicity as proposed in Frandsen, Lefgren, and Leslie (2020) where they show that average monotonicity can suffice in lieu of strict monotonicity if the average treatment propensities move in the same dirction as their potential treatment decisions. In the context of our paper, we can relax strict monotonicity for any given clinician as long as the individual monotonically complies with enough other judges. Thus, the coefficients should all be significant and the same direction to support average monotonicity.}\\"
	}

	#delimit ;
		esttab using "${tables}/${filelab}_avg_mono_`subsamp'.tex",
			booktabs
			style(tex) label notype
			keep(z_$fs_out)
			cells((b(star fmt(%9.3f))) (se(fmt(%9.3f)par)))
			starlevels(* 0.10 ** 0.05 *** 0.01)
			stats(N t_fe controls,
				labels("Observations"
						"Time Fixed Effects" "Controls")
				fmt(%9.0fc %9.0fc %9.3fc %9.2fc %9.0fc))
			replace noabbrev
			title("Average Montonicity for Initial Assessment of ${fs_lab} for `varlab'")
			numbers collabels(none) eqlabels(none) mlabels(none)
			mgroups("Male" "Female" "Black" "White" "Hispanic" , pattern(1 1 1 1 1 )
				prefix(\multicolumn{@span}{c}{)
				suffix(}) span erepeat(\cmidrule(lr){@span}))
			varlabels(,prefix("\multirow[t]{2}{.32\textwidth}{\hangindent=2em") suffix("}"))
			prehead(
					"\begin{tabular}{p{.4\textwidth}*{@E}{c}}"
					"\toprule"
					)
			posthead("\midrule")
			postfoot("\bottomrule"
					 "`footnote'"
					"\end{tabular}")
			;
	#delimit cr
	//"\multicolumn{6}{l}{\textbf{`age_samp'}}\\"
	eststo clear
	frame change default
	}









	********************************************************************************
	* Complier Analysis
	********************************************************************************

	frame change default
	use "$data/${filelab}_final.dta", clear

	**** Complier Means
	eststo clear
	// complier means overall

	frame copy default ar_ci, replace
	frame change ar_ci
		cap drop comp_treat
		gen comp_treat = 1-$fs_out
		label var comp_treat "Complier Means ${fs_lab}"

		cap file close myfile
		file open myfile using "$tables/${filelab}_complier_means.tex", write replace
		file write myfile 	"\caption{Complier Means of Outcomes for ${fs_lab}}" ///
							"\begin{tabular}{l*{2}{c}}" _n ///
							"\toprule" _n ///
							"	& \textbf{Transition Age} & \textbf{Adults}\\" _n ///
							"\midrule" _n
		
		
		* TAY
		foreach var in $outcomes {
			cap drop comp_`var'
			gen comp_`var' = `var' * (comp_treat)
			
			* TAY
			ivreghdfe comp_`var' ( comp_treat = z_$fs_out ) $demogs if age < 26 , a($time_fe ) clust( $clust )
			// store estimates of means and add them to results table
			local `var'_comp_mean1  : di %9.3fc `=_b[comp_treat]' //format %9.3fc
			local `var'_comp_se1  : di %9.3fc `=_se[comp_treat]'
			local var_label : variable label `var'
			
			*Adults
			ivreghdfe comp_`var' ( comp_treat = z_$fs_out ) $demogs if age >= 26, a($time_fe ) clust( $clust )
			// store estimates of means and add them to results table
			local `var'_comp_mean2  : di %9.3fc `=_b[comp_treat]'
			local `var'_comp_se2  : di %9.3fc `=_se[comp_treat]'
			
			file write myfile "`var_label' & ``var'_comp_mean1' & ``var'_comp_mean2' \\" _n ///
								"	&	(``var'_comp_se1') &	(``var'_comp_se1') \\" _n
		}
					

					file write myfile 	"\bottomrule" _n ///
										"\multicolumn{3}{p{3in}}{\footnotesize Notes: This table reports the complier mean and standard error (in parentheses) for each dependent variable.}" _n ///
										"\end{tabular}"

					file close myfile
					
					
					
	*** Complier characteristics
	cap file close myfile
		file open myfile using "$tables/${filelab}_complier_chars.tex", write replace
		file write myfile 	"\caption{Complier Means of Characteristics for ${fs_lab}}" ///
							"\begin{tabular}{l*{2}{c}}" _n ///
							"\toprule" _n ///
							"	& \textbf{Transition Age} & \textbf{Adults}\\" _n ///
							"\midrule" _n
	foreach var in $demogs {
			cap drop comp_`var'
			gen comp_`var' = `var' * (comp_treat)
			
			* prevent collinearity
			local demogs : list global(demogs) - local(var)
			
			* TAY
			ivreghdfe comp_`var' ( comp_treat = z_$fs_out ) $demogs if age < 26 , a($time_fe ) clust( $clust )
			// store estimates of means and add them to results table
			local `var'_comp_mean1  : di %9.3fc `=_b[comp_treat]' //format %9.3fc
			local `var'_comp_se1  : di %9.3fc `=_se[comp_treat]'
			local var_label : variable label `var'
			
			*Adults
			ivreghdfe comp_`var' ( comp_treat = z_$fs_out ) $demogs if age >= 26, a($time_fe ) clust( $clust )
			// store estimates of means and add them to results table
			local `var'_comp_mean2  : di %9.3fc `=_b[comp_treat]'
			local `var'_comp_se2  : di %9.3fc `=_se[comp_treat]'
			
			file write myfile "`var_label' & ``var'_comp_mean1' & ``var'_comp_mean2' \\" _n ///
								"	&	(``var'_comp_se1') &	(``var'_comp_se1') \\" _n
		}
					

					file write myfile 	"\bottomrule" _n ///
										"\multicolumn{3}{p{3in}}{\footnotesize Notes: This table reports the complier mean and standard error (in parentheses) for each characteristic variable.}" _n ///
										"\end{tabular}"

					file close myfile
	frame change default

}


