/*******************************************************************************
*		Analysis
*******************************************************************************/
frame change default
use "$data/${filelab}_final.dta", clear

local tay_mis_obs 11147
local adult_mis_obs 30643
local tay_fel_obs 9227
local adult_fel_obs 27515



* Set footnotes for subsample analyses
if inlist("${filelab}", "mis_black", "fel_black") {
	qui sum sa_hazard
	if "${filelab}" == "mis_black" {
		local calc = 100 * `r(N)' / 41789
	}
	else{
		local calc = 100 * `r(N)' / 36742
	}
	local pct_N : di %3.0fc `calc'
	
	local extra_fn "The race variables were dropped from the baseline controls in these models as this specification only considers individuals who identify as Black. This subsample is approximately `pct_N' percent of the primary sample."
} 
else if inlist("${filelab}", "mis_white", "fel_white") {
	qui sum sa_hazard
	if "${filelab}" == "mis_white" {
		local calc = 100 * `r(N)' / 41789
	}
	else{
		local calc = 100 * `r(N)' / 36742
	}
	local pct_N : di %3.0fc `calc'
	
	local extra_fn "The race variables were dropped from the baseline controls in these models as this specification only considers individuals who identify as White. This subsample is approximately `pct_N' percent of the primary sample."
}
else if inlist("${filelab}", "mis_hisp", "fel_hisp") {
	qui sum sa_hazard
	if "${filelab}" == "mis_hisp" {
		local calc = 100 * `r(N)' / 41789
	}
	else{
		local calc = 100 * `r(N)' / 36742
	}
	local pct_N : di %3.0fc `calc'
	
	local extra_fn "The ethnicity variable was dropped from the baseline controls in these models as this specification only considers individuals who identify as Hispanic. This subsample is approximately `pct_N' percent of the primary sample."
}
else if inlist("${filelab}", "mis_complier","fel_complier") {
	qui sum sa_hazard
	if "${filelab}" == "mis_complier" {
		local calc = 100 * `r(N)' / 41789
	}
	else{
		local calc = 100 * `r(N)' / 36742
	}
	local pct_N : di %3.0fc `calc'
	
	local extra_fn "These models limit the sample to individuals labeled as having mild (1) or moderate (2) mental health needs. This subsample is approximately `pct_N' percent of the primary sample."
}
else if inlist("${filelab}", "mis_over500cases", "fel_over500cases") {
	qui sum sa_hazard
	if "${filelab}" == "mis_over500cases" {
		local calc = 100 * `r(N)' / 41789
	}
	else{
		local calc = 100 * `r(N)' / 36742
	}
	local pct_N : di %3.0fc `calc'
	
	local extra_fn "These models limit the sample to clinicians that see at lease 500 cases in the dataset. This subsample is approximately `pct_N' percent of the primary sample."
}
else if inlist("${filelab}", "mis_trunc", "fel_trunc") {
	qui sum sa_hazard
	if "${filelab}" == "mis_trunc" {
		local calc = 100 * `r(N)' / 41789
	}
	else{
		local calc = 100 * `r(N)' / 36742
	}
	local pct_N : di %3.0fc `calc'
	
	local extra_fn "These models truncate the sample 1 year prior to the last date of available data to ensure that everyone has the opportunity to recidivate up to 12 months after release. This subsample is approximately `pct_N' percent of the primary sample."
}
else if inlist("${filelab}", "mis_yr_18_19", "fel_yr_18_19") {
	qui sum sa_hazard
	if "${filelab}" == "mis_yr_18_19" {
		local calc = 100 * `r(N)' / 41789
	}
	else{
		local calc = 100 * `r(N)' / 36742
	}
	local pct_N : di %3.0fc `calc'
	
	local extra_fn "These models limit the sample to 2018-2019. In addition to the baseline controls, we include prior psychiatric medication use and prior psychiatric hospitalization as covariates. This subsample is approximately `pct_N' percent of the primary sample."
}
else if inlist("${filelab}", "mis_no_tcu_18_19", "fel_no_tcu_18_19") {
	qui sum sa_hazard
	if "${filelab}" == "mis_yr_18_19" {
		local calc = 100 * `r(N)' / 41789
	}
	else{
		local calc = 100 * `r(N)' / 36742
	}
	local pct_N : di %3.0fc `calc'
	
	local extra_fn "These models limit the sample to 2018-2019 and remove any booking during which an individual indicates drug or alcohol use in the last 12 months. In addition to the baseline controls, we include prior psychiatric medication use and prior psychiatric hospitalization as covariates. This subsample is approximately `pct_N' percent of the primary sample."
}
else {
	local extra_fn ""
}

********************************************************************************
*  OLS/2SLS/IVLASSO: Main outcome table with Anderson-Rubin Confidence Intervals
********************************************************************************


do "$code/ar_ci_regs.do"

eststo clear
local outcome_list $outcomes
local dem $demogs
local outcome_list : subinstr local outcome_list " " ", ", all
local outcome_list `" `outcome_list' "'

*  Run regressions within mis/fel: TAY first, then adults
	forval age_group = 0/1 {
		frame change default
		// OLS
			frame copy default ar_ci, replace
			frame change ar_ci
			keep if adults == `age_group'
		regs_arci "ols" `" `outcome_list' "' "$demogs"
		
		// 2SLS
		frame change default
			frame copy default ar_ci, replace
			frame change ar_ci
			keep if adults == `age_group'
		regs_arci "2sls" "`outcome_list'" "$demogs"
		
		// LASSO
		frame change default
			frame copy default ar_ci, replace
			frame change ar_ci
			keep if adults == `age_group'
		foreach var of varlist $outcomes {
			eststo `var': qui ivlasso `var' ($fs_out = clinician_dd* ) ( $demogs i.$time_fe ) , lopt(prestd robust) ivoptions(cluster($clust )) sscset post(lasso) 
		}
		local demogs_flag "Yes"
		run "$code/vert_output.do"
		rotate_reg_output "`demogs_flag'"
		frame change default
	}

* Output table to latex format
	#delimit ;
			esttab using "$tables/${filelab}_main_regs.tex", replace label 
			booktabs style(tex)
			cells(b(fmt(%9.3f) star pvalue(p)) se(fmt(%9.3f) par) 
				CIL(fmt(%9.3f) par("[" "" )) & CIU(fmt(%9.3f) par("" "]"))) 
			starlevels(* 0.10 ** 0.05 *** 0.01)
			substitute("\_" "_")
			stats(t_fe controls,
				labels("Time fixed effects" "Baseline Controls"))
			title("Effects of Initial Assessment of ${fs_lab}")
			numbers
			collabels(none) eqlabels(none) mlabels("OLS" "2SLS" "IVLASSO" "OLS" "2SLS" "IVLASSO")
			mgroups("Transition Age" "Adults", pattern(1 0 0 1 0 0)
				prefix(\multicolumn{@span}{c}{)
				suffix(}) span erepeat(\cmidrule(lr){@span}))
			varlabels(,prefix("\multirow{2}{.25\textwidth}{\hangindent=2em") suffix("}"))
			prehead("\begin{table}[htbp]"
				"\centering"
				"\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}"
				"\caption{@title}\label{tab:${filelab}_mainmh}"
				"\begin{tabular}{p{.25\textwidth}*{@E}{c}}"
				"\toprule")
			postfoot("\bottomrule"
				"\multicolumn{@span}{p{7.4in}}{\footnotesize Notes: This table reports the ordinary least squares (OLS), two-stage least squares (2SLS), and the instrumental variables LASSO (IVLASSO) estimates of the impact of being assigned a moderate/severe mental health needs rating. The dependent variable is listed in each row. The recidivism within 1 year sample is truncated to 1 year prior to the last date our dataset. Similarly, the recidivism within 18 months and 2 years samples are truncated to 18 months and 2 years prior to the last date. The 2SLS and IVLASSO specifications instrument for assignation of a high mental health needs score using a clinician leniency measure that is estimated using data from other cases assigned to a clinician as described in the text. We include ${time_lab} fixed effects and baseline controls for all specifications. `extra_fn' The clinician and inmate robust two-way clustered standard errors are shown in parentheses. For the 2SLS estimates, confidence intervals based on the inversion of the Anderson-Rubin test are shown in brackets. \newline * p$<$0.10, ** p$<$0.05, *** p$<$0.01}"
				"\end{tabular}"
				"\end{table}")
			;
		#delimit cr

* Output table to word format
if "${filelab}" == "mis" {
	#delimit ;
			esttab using "$tables/reg_tables", replace label
			rtf onecell
			cells(b(fmt(%9.3f) star pvalue(p)) se(fmt(%9.3f) par) 
				CIL(fmt(%9.3f) par("[" "" )) & CIU(fmt(%9.3f) par("" "]"))) 
			starlevels(* 0.10 ** 0.05 *** 0.01)
			stats(t_fe controls,
				labels("Time fixed effects" "Baseline Controls"))
			title("Effects of Initial Assessment of ${fs_lab}")
			numbers
			collabels(none) eqlabels(none) mlabels("OLS" "2SLS" "IVLASSO" "OLS" "2SLS" "IVLASSO")
			mgroups("Transition Age" "Adults", pattern(1 0 0 1 0 0))
			addnotes("Notes: This table reports the ordinary least squares (OLS), two-stage least squares (2SLS), and the instrumental variables LASSO (IVLASSO) estimates of the impact of being assigned a moderate/severe mental health needs rating. The dependent variable is listed in each row. The recidivism within 1 year sample is truncated to 1 year prior to the last date our dataset. Similarly, the recidivism within 18 months and 2 years samples are truncated to 18 months and 2 years prior to the last date. The 2SLS and IVLASSO specifications instrument for assignation of a high mental health needs score using a clinician leniency measure that is estimated using data from other cases assigned to a clinician as described in the text. We include ${time_lab} fixed effects and baseline controls for all specifications. `extra_fn' The clinician and inmate robust two-way clustered standard errors are shown in parentheses. For the 2SLS estimates, confidence intervals based on the inversion of the Anderson-Rubin test are shown in brackets. \newline * p$<$0.10, ** p$<$0.05, *** p$<$0.01"
				)
			;
		#delimit cr
}
else {
	#delimit ;
			esttab using "$tables/reg_tables", append label
			rtf onecell
			cells(b(fmt(%9.3f) star pvalue(p)) se(fmt(%9.3f) par) 
				CIL(fmt(%9.3f) par("[" "" )) & CIU(fmt(%9.3f) par("" "]"))) 
			starlevels(* 0.10 ** 0.05 *** 0.01)
			stats(t_fe controls,
				labels("Time fixed effects" "Baseline Controls"))
			title("Effects of Initial Assessment of ${fs_lab}")
			numbers
			collabels(none) eqlabels(none) mlabels("OLS" "2SLS" "IVLASSO" "OLS" "2SLS" "IVLASSO")
			mgroups("Transition Age" "Adults", pattern(1 0 0 1 0 0))
			addnotes("Notes: This table reports the ordinary least squares (OLS), two-stage least squares (2SLS), and the instrumental variables LASSO (IVLASSO) estimates of the impact of being assigned a moderate/severe mental health needs rating. The dependent variable is listed in each row. The recidivism within 1 year sample is truncated to 1 year prior to the last date our dataset. Similarly, the recidivism within 18 months and 2 years samples are truncated to 18 months and 2 years prior to the last date. The 2SLS and IVLASSO specifications instrument for assignation of a high mental health needs score using a clinician leniency measure that is estimated using data from other cases assigned to a clinician as described in the text. We include ${time_lab} fixed effects and baseline controls for all specifications. `extra_fn' The clinician and inmate robust two-way clustered standard errors are shown in parentheses. For the 2SLS estimates, confidence intervals based on the inversion of the Anderson-Rubin test are shown in brackets. \newline * p$<$0.10, ** p$<$0.05, *** p$<$0.01"
				)
			;
		#delimit cr	
}
frame change default
	
	
	